@@ -5,122 +5,10 @@
 #This file contains everything that needs to be accessed by most or all files.
 
 
-#Dragon Hunt 3.26. Released under the GPL. Copyright 2004
+#Dragon Hunt 3.28. Released under the GPL. Copyright 2004
 #(Note to self: when changing version, change variables.txt, README.txt,
 # and setup.py.)
 
-#TODO
-#Monster scripts.
-#Item scripts.
-#Take out cur_mon_hp next time the savegame format is changed.
-#Roll own dialog boxes/remove tkinter widgets.
-#hp/ep recovery scripts
-
-#Changelog:
-
-#3.26
-#Allowed continuing after winning.
-#Fixed give gold bug.
-#Expanded level 1.
-#Added monster descriptions. (Allison Marles)
-#Added sell item message. (Allison Marles)
-#Game plays well with CVS now. (Allison Marles)
-#Can see monster attack/defense.
-#Loadgame screen works better with no saves.
-#Better item/skill mouse control in battle.
-#Moved inventory to main window.
-#Moved game name to external file.
-#Directory name no longer matters in modules.
-#Placed new game dice in variables.txt.
-#Allowed "\" line-continuation in items.txt.
-#Put shop data in text file.
-#Added addskill scripting command.
-#Added attack and defense training.
-
-#3.25
-#Allowed subdirectories in the tiles directory.
-#Allowed =,<,>,<=,>= in if command.
-#Allowed +,-,= in set command.
-#Added stat scripting command.
-#Allowed multiple quests.
-#Added underground tiles.
-#Changed hero graphics.
-#Enhanced level 2.
-#Moved store/battle from window to frame. (Allison Marles)
-#Added message scroller. (Allison Marles)
-#Added monster picture ability. (Allison Marles)
-
-#3.24
-#Fixed bug with using items with full inventory.
-#All screens can now be entirely controlled by keyboard.
-#Can now move with mouse.
-#Moved tiles to images/tiles
-#Added button images.
-#Allowed any picture for the off-screen area.
-
-#3.23
-#Fixed bugs with starting new games with loaded characters.
-#Changed map scripting to onload, action sections.
-#Added 1 more item, finished descriptions.
-#Added numbers as allowable script commands.
-#Allowed commands instead of numbers in some commands.
-#Changed scripting to central file, to allow scripting in other places.
-#Added levelup script.
-#Added hp/ep bars.
-
-#3.22
-#Changed xp rewarding; deeper diving is now encouraged.
-#Added run scripting command.
-#Changed map difficulty from numerical to a list of monsters.
-#Changed monster reward from calculated to manual.
-#Centralized movement code.
-
-#3.21
-#Save directory will now be created properly.
-#Player cannot walk around while inside a store anymore.
-#Added newgame script.
-#Added town graphics.
-#Added refresh scripting command.
-#Eased up on the difficulty somewhat.
-
-#3.2
-#Fixed focus bug in inventory.
-#Fixed errors when trying to move in the newgame screen.
-#Check for/create saves directory.
-#Moved monster, map, and item lists to external files.
-#Moved version info to fewer locations.
-#Added a couple more item descriptions.
-#Added scripting engine
-#Increased hp/ep recovery time.
-#Started 3.2 savefile style for scripting variables.
-#Added a small story.
-
-#3.1
-#Added skillpoints/ep usage.
-#Changed Save/load game item storage to use names, not id,
-# to increase compatability between versions.
-#Started new savegame style, 3.1, to add skills and item names.
-#Changed line length to < 80 characters throughout code.
-#Gave starting characters more gold, less ep.
-#Levelup gives more maxhp, less maxep.
-#Moved item use to inside battle.py. There may be a couple
-# leftover variables from the move that need cleaning up.
-#Fixed bug where game was not reset after dying.
-#Fixed bug where the battle display would not update upon trying to run.
-#Fixed bug where buy button would remain active after running out of money.
-
-#3.0a
-#added stores, save/load game ability, few other things
-
-#3.0
-#started from scratch, writing Dragon Hunt in Python this time,
-#as 1) I don't have a Visual Basic compiler anymore, and 2) I
-#am running Linux now, making it difficult for me to run one in
-#any case, and 3) I needed to learn Python. Features are about
-#the same as 2.0, though there are a few improvements that came
-#along for the ride, along with a few incomplete areas.
-
-
 from Tkinter import *
 import ImageTk
 #needed for die_roll
@@ -192,6 +80,9 @@ def drop_inv_item(num):
 		inv[i-1]=inv[i]
 	inv[len(inv)-1] = -1
 
+#default tile width. Set in variables.txt, or default to 32.
+tilesize = 32
+
 #location on map: x, y, z coordinate. Map names are given a zgrid on loading.
 xgrid = 0
 ygrid = 0
@@ -209,7 +100,7 @@ var_list = {}
 cur_mon_hp = 0
 
 #Name of current hero picture.
-cur_hero = "hero_w.png"
+cur_hero = "people/hero_w.png"
 
 #Should the player be allowed to move? Used with the move scripting command,
 #to prevent moving again after moving.
@@ -402,6 +293,9 @@ def read_variables():
 			read_dice(3, line.split("=", 1)[1].strip())
 		elif (line.split("=", 1)[0].strip() == "gold"):
 			read_dice(4, line.split("=", 1)[1].strip())
+		elif (line.split("=", 1)[0].strip() == "tilesize"):
+			global tilesize
+			tilesize = int(line.split("=", 1)[1].strip())
 		line = file.readline()
 
 #given a dice set and string of the form 2d4+5, place in new_game_dice
@@ -622,15 +516,15 @@ def checklocation(x, y):
 
 	#Assume that all off-map areas are rock.
 	if x < 0 or y < 0:
-		return '1'
+		return 'a'
 	try:
 		#this will fail when looking too far right or down
-		return maps[zgrid].field[y][x]
+		return maps[zgrid].field[y][x].name
 	except IndexError:
 		#off the map, so rock.
-		return '1'
+		return 'a'
 
-#like checklocation, but just returns 1 (rock) or 0 (grass)
+#like checklocation, but just returns 0 (rock) or 1 (grass)
 def iswalkable(x, y):
 	#transform from relative to absolute coordinates
 	x = xgrid + x
@@ -638,15 +532,15 @@ def iswalkable(x, y):
 
 	#Assume that all off-map areas are rock.
 	if x < 0 or y < 0:
-		return '1'
+		return 0
 	try:
 		#this will fail when looking too far right or down
-		if maps[zgrid].tiles[maps[zgrid].field[y][x]].walk == 1:
-			return '1'
+		if maps[zgrid].field[y][x].walk == 0:
+			return 0
 	except IndexError:
-		return '1'
+		return 0
 	#By this point, it is known to be walkable.
-	return 0
+	return 1
 
 #takes the name of a map, and returns its zgrid.
 def mapname2zgrid(name):
