@@ -21,13 +21,14 @@ import shop
 import action
 
 #size, in tiles, of the main screen. While this is adjustable,
-#an odd number would work much better. (Keep the player centered.)
+#an odd number would work much better. (To keep the player centered.)
 mapsize = 13
 
 sidebarsize = 5
 status_box_width = 19
 width = 20
-status_box_height =10
+status_box_height =6
+tilesize = 32
 
 
 #max number of messages to keep.
@@ -74,6 +75,7 @@ def dead_yet():
 	if g.hp <= 0:
 		action.activate_line(g.xgrid, g.ygrid, g.zgrid, "die")
 		return 1
+	return 0
 
 #back to main menu. Called on death.
 def close_window(event=0):
@@ -85,18 +87,20 @@ def close_window(event=0):
 
 #Activate any scripting associated with a tile. X and Y are relative
 #to the location of the player.
-#assumes scripting stored in maps[zgrid].tiles[checklocation(x, y)].actions[]
+#assumes scripting stored in maps[zgrid].field[y][x].actions[]
 def activate_scripting(x, y, z):
-	tile_type = g.checklocation(x, y)
 	return_num = 0
+	temp_xgrid = x + g.xgrid
+	temp_ygrid = y + g.ygrid
 	temp_zgrid = z
 	#if there are no actions, leave immediately
-	if len(g.maps[temp_zgrid].tiles[tile_type].actions) == 0: return
+	if len(g.maps[temp_zgrid].field[y+g.ygrid][x+g.xgrid].actions) == 0: return
+
 	i = 0
 	#go through all action lines.
-	while i < len(g.maps[temp_zgrid].tiles[tile_type].actions):
+	while i < len(g.maps[temp_zgrid].field[temp_ygrid][temp_xgrid].actions):
 		temp = action.activate_line(x, y, z,
-			g.maps[temp_zgrid].tiles[tile_type].actions[i])
+			g.maps[temp_zgrid].field[temp_ygrid][temp_xgrid].actions[i])
 		if temp == "end": break
 		if dead_yet() == 1:
 			break
@@ -106,30 +110,31 @@ def activate_scripting(x, y, z):
 #redraws the main map. Call after moving.
 def refreshmap():
 	#redraw the tiles
+	half_map = mapsize/2 #division is nasty. Only do it once.
+	canvas_map.delete("all")
 	for x in range(mapsize):
 		for y in range(mapsize):
-			type = g.checklocation(x-mapsize/2, y-mapsize/2)
-			label_map[y*mapsize+x].config(image=findtile(x-mapsize/2,
-				y-mapsize/2))
+			for picture in findtile(x-half_map, y-half_map):
+				canvas_map.create_image(x*g.tilesize, y*g.tilesize,
+					anchor=NW, image=picture)
 
-	canvas_char.delete("all")
-	canvas_char.create_image(0, 0, anchor=NW, image=findtile(0, 0))
-	canvas_char.create_image(0, 0, anchor=NW, image=g.tiles[g.cur_hero])
+
+	canvas_map.create_image(mapsize*g.tilesize/2, mapsize*g.tilesize/2,
+		image=g.tiles[g.cur_hero])
 
 	recalc_stats()
 
 #called to process the onload portion of a level. Called whenever entering
 #a level. Set g.zgrid properly before calling.
 def process_onload():
-	for tile_type in g.maps[g.zgrid].tiles:
-		return_num = 0
-		#if there are no actions, leave immediately
-		if len(g.maps[g.zgrid].tiles[tile_type].onload) == 0: return
-		i = 0
-		#go through all action lines.
-		for i in range(len(g.maps[g.zgrid].tiles[tile_type].onload)):
-			temp = action.activate_line(-1, -1, g.zgrid,
-				g.maps[g.zgrid].tiles[tile_type].onload[i], tile_type)
+	for y in range(len(g.maps[g.zgrid].field)):
+		for x in range(len(g.maps[g.zgrid].field[y])):
+			return_num = 0
+			i = 0
+			#go through all action lines.
+			for i in range(len(g.maps[g.zgrid].field[y][x].onload)):
+				temp = action.activate_line(x, y, g.zgrid,
+					g.maps[g.zgrid].field[y][x].onload[i])
 
 #recalculate and display stats
 def recalc_stats():
@@ -164,28 +169,34 @@ def recalc_stats():
 	exp.set(g.exp)
 	level.set(g.level)
 
-#takes x and y relative to the player, and returns the image needed
-#to display that location.
+
 def findtile(x, y):
+	#g.maps[g.zgrid].field[][].pix)
 	#transform from relative to absolute coordinates
 	x = g.xgrid + x
 	y = g.ygrid + y
 
+	returnpix = []
 	#Assume that all off-map areas are rock.
 	if x < 0 or y < 0:
-		return g.maps[g.zgrid].tiles["1"].pix
+		returnpix.append(g.maps[g.zgrid].field[0][0].pix)
+		return returnpix
 	try:
 		#this will fail when looking too far right or down
-		return g.maps[g.zgrid].tiles[g.maps[g.zgrid].field[y][x]].pix
+		returnpix.append(g.maps[g.zgrid].field[y][x].pix)
+		for picture in g.maps[g.zgrid].field[y][x].addpix:
+			returnpix.append(picture)
+		return returnpix
 	except IndexError:
 		#If it fails, there is rock there.
-		return g.maps[g.zgrid].tiles["1"].pix
+		returnpix.append(g.maps[g.zgrid].field[0][0].pix)
+		return returnpix
 	except KeyError:
 		#if the author forgot to define the tile, point out the mistake.
 		print "Tile of " + g.maps[g.zgrid].field[y][x] + " is not defined" \
 			+ " in map " + g.maps[g.zgrid].name
-		return g.maps[g.zgrid].tiles["1"].pix
-
+		returnpix.append(g.maps[g.zgrid].tiles["a"].pix)
+		return returnpix
 
 
 #movement commands. Check to see if window_main is visible, and if there is no
@@ -200,21 +211,21 @@ def move_hero(x, y):
 		#check for any objects of interest.
 		activate_scripting(x, y, g.zgrid)
 
-		if g.iswalkable(x, y) != '1':
+		if g.iswalkable(x, y):
 			if g.allow_move == 1:
 				g.xgrid=g.xgrid + x
 				g.ygrid=g.ygrid + y
 				passturn()
-				if y == -1: g.cur_hero = "hero_n.png"
-				if y ==  1: g.cur_hero = "hero_s.png"
-				if x == -1: g.cur_hero = "hero_w.png"
-				if x ==  1: g.cur_hero = "hero_e.png"
+				if y == -1: g.cur_hero = "people/hero_n.png"
+				if y ==  1: g.cur_hero = "people/hero_s.png"
+				if x == -1: g.cur_hero = "people/hero_w.png"
+				if x ==  1: g.cur_hero = "people/hero_e.png"
 				refreshmap()
 		else:
-			if y == -1: g.cur_hero = "hero_n.png"
-			if y ==  1: g.cur_hero = "hero_s.png"
-			if x == -1: g.cur_hero = "hero_w.png"
-			if x ==  1: g.cur_hero = "hero_e.png"
+			if y == -1: g.cur_hero = "people/hero_n.png"
+			if y ==  1: g.cur_hero = "people/hero_s.png"
+			if x == -1: g.cur_hero = "people/hero_w.png"
+			if x ==  1: g.cur_hero = "people/hero_e.png"
 			refreshmap()
 		g.allow_move = 1
 	except TclError:
@@ -317,25 +328,18 @@ def init_window_main(new_game = 0):
 	global listbox_status
 	listbox_status = Listbox(window_main, height=status_box_height,
 		bg=statusboxcolour)
-	listbox_status.grid(row=1, column=0, sticky=EW) #status_box_width)
+	listbox_status.grid(row=1, column=0, sticky=N+S+E+W) #status_box_width)
 	move_scroll = Scrollbar(window_main, orient=VERTICAL,
 		command=listbox_status.yview, bg=statusboxcolour)
 	move_scroll.grid(row=1, column=0, sticky=N+S+E)
 	listbox_status.config(yscrollcommand=move_scroll.set)
+	window_main.rowconfigure(1, weight=1)
 
 
 	g.load_tiles()
 
-	#At this point, the actual files are in tiles[filename]
-	#Assign pictures to actual tiles.
-	for mapindex in range(len(g.maps)):
-		for tilename in g.maps[mapindex].tiles:
-			 g.maps[mapindex].tiles[tilename].pix = \
-			 	g.tiles[g.maps[mapindex].tiles[tilename].pixname]
-	#now each tile has a name and an actual picture.
-
 	#width of the hp/ep bars.
-	g.hpbar_width = g.tiles["grass.png"].width()*3
+	g.hpbar_width = g.tilesize*3
 
 	name.set(g.name)
 
@@ -412,11 +416,11 @@ def init_window_main(new_game = 0):
 
 	#put in the map, and do finishing touches on the window.
 	process_onload()
-	g.cur_hero = "hero_w.png"
+	g.cur_hero = "people/hero_w.png"
 	refreshmap()
 	window_main.wm_geometry("+%d+%d" % (10, 10))
 	window_main.focus()
-	window_main.resizable(0, 0)
+	window_main.resizable(width=0, height=0)
 	window_main.title(g.game_name)
 	global free_move
 	free_move = 0
@@ -450,6 +454,14 @@ def bind_keys():
 	window_main.bind("q", close_window)
 	window_main.bind("<Return>", show_inv)
 
+#handles mouse clicks on the main tile canvas.
+def mouse_handler(event=0):
+	if (event.x < event.y): #south or west
+		if (event.x + event.y > mapsize*g.tilesize): move_south()
+		else: move_west()
+	else: #north or east
+		if (event.x + event.y > mapsize*g.tilesize): move_east()
+		else: move_north()
 
 
 def create_map():
@@ -457,33 +469,11 @@ def create_map():
 	global right
 	right = Frame(top,bd=2, relief=SUNKEN, bg=bgcolour);
 	right.grid(row=1, column=sidebarsize, columnspan=mapsize, sticky=E)
-
-	#this creates the actual map portion.
-	global label_map
-	label_map = []
-	for x in range(mapsize):
-		for y in range(mapsize):
-			label_map.append(x*mapsize+y)
-			label_map[x*mapsize+y] = Label(right,
-				image=g.tiles["blank"], borderwidth=0)
-			if (x < y): #north or east
-				if (x + y > mapsize-1): #east
-					label_map[x*mapsize+y].bind("<Button-1>", move_east)
-				elif(x + y < mapsize-1): #north
-					label_map[x*mapsize+y].bind("<Button-1>", move_north)
-			elif (x > y): #south or west
-				if (x + y > mapsize-1): #south
-					label_map[x*mapsize+y].bind("<Button-1>", move_south)
-				elif(x + y < mapsize-1): #west
-					label_map[x*mapsize+y].bind("<Button-1>", move_west)
-			label_map[x*mapsize+y].grid(column=y, row=x)
-
-
-	#this creates the transparent Player tile.
-	global canvas_char
-	canvas_char = Canvas(right, width=g.tiles["grass.png"].width(),
-		height=g.tiles["grass.png"].height(), highlightthickness=0)
-	canvas_char.grid(column=mapsize/2, row=mapsize/2)
+	global canvas_map
+	canvas_map = Canvas(right, width=g.tilesize*mapsize,
+		height=g.tilesize*mapsize, highlightthickness=0)
+	canvas_map.grid(column=0, row=0)
+	canvas_map.bind("<Button-1>", mouse_handler)
 
 #show the inventory.
 def show_inv(event=0):
